@@ -16,7 +16,7 @@ fn assert_processed_path_matches(path: &str, prefix: &str, extension: &str) {
     assert!(filename.ends_with(&suffix), "Path `{}` doesn't end with `{}`", path, suffix);
 }
 
-static CONFIG: &str = r#"
+const CONFIG: &str = r#"
 title = "imageproc integration tests"
 base_url = "https://example.com"
 compile_sass = false
@@ -127,6 +127,11 @@ fn resize_image_png_webp() {
     image_op_test("png.png", "scale", Some(150), Some(150), "webp", "webp", 150, 150, 300, 380);
 }
 
+#[test]
+fn resize_image_png_avif() {
+    image_op_test("png.png", "scale", Some(150), Some(150), "avif", "avif", 150, 150, 300, 380);
+}
+
 #[test]
 fn resize_image_webp_jpg() {
     image_op_test("webp.webp", "scale", Some(150), Some(150), "auto", "jpg", 150, 150, 300, 380);
@@ -179,6 +184,19 @@ fn read_image_metadata_webp() {
     );
 }
 
+#[test]
+fn read_image_metadata_avif() {
+    assert_eq!(
+        image_meta_test("avif.avif"),
+        ImageMetaResponse {
+            width: 300,
+            height: 380,
+            format: Some("avif"),
+            mime: Some("image/avif")
+        }
+    );
+}
+
 #[test]
 fn fix_orientation_test() {
     fn load_img_and_fix_orientation(img_name: &str) -> DynamicImage {
